@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2018 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -19,8 +19,8 @@ from __future__ import division, print_function, absolute_import
 
 import inspect
 
-from hypothesis._settings import settings, Verbosity
-from hypothesis.internal.compat import print_unicode, \
+from hypothesis._settings import Verbosity, settings
+from hypothesis.internal.compat import binary_type, print_unicode, \
     escape_unicode_characters
 from hypothesis.utils.dynamicvariables import DynamicVariable
 
@@ -54,7 +54,7 @@ def current_verbosity():
 def to_text(textish):
     if inspect.isfunction(textish):
         textish = textish()
-    if isinstance(textish, bytes):
+    if isinstance(textish, binary_type):
         textish = textish.decode('utf-8')
     return textish
 
